/**
 * SMTP Server Module Exports
 * This file exports all components of the refactored SMTP server
 */

// Export interfaces
export * from './interfaces.js';

// Export server classes
export { SmtpServer } from './smtp-server.js';
export { SessionManager } from './session-manager.js';
export { ConnectionManager } from './connection-manager.js';
export { CommandHandler } from './command-handler.js';
export { DataHandler } from './data-handler.js';
export { TlsHandler } from './tls-handler.js';
export { SecurityHandler } from './security-handler.js';

// Export constants
export * from './constants.js';

// Export utilities
export { SmtpLogger } from './utils/logging.js';
export * from './utils/validation.js';
export * from './utils/helpers.js';

// Export TLS and certificate utilities
export * from './certificate-utils.js';
export * from './secure-server.js';
export * from './starttls-handler.js';

// Factory function to create a complete SMTP server with default components
export { createSmtpServer } from './create-server.js';